@@ -28,21 +28,14 @@ import json
 import re
 from omero.rtypes import unwrap
 from future.utils import bytes_to_native_str
-
-try:
-    import yaml
-    YAML_ENABLED = True
-except ImportError:
-    YAML_ENABLED = False
+import yaml
 
 
 def get_supported_formats():
     """
     Return the supported formats
     """
-    if YAML_ENABLED:
-        return ('json', 'yaml')
-    return ('json',)
+    return ('json', 'yaml')
 
 
 def load(fileobj, filetype=None, single=True, session=None):
@@ -77,9 +70,7 @@ def load(fileobj, filetype=None, single=True, session=None):
         rawdata, filetype = get_format_filename(fileobj, filetype)
 
     if filetype == 'yaml':
-        if not YAML_ENABLED:
-            raise ImportError("yaml (PyYAML) module required")
-        data = list(yaml.load_all(rawdata))
+        data = list(yaml.safe_load_all(rawdata))
         if single:
             if len(data) != 1:
                 raise Exception(
@@ -108,8 +99,6 @@ def dump(data, formattype):
     """
 
     if formattype == 'yaml':
-        if not YAML_ENABLED:
-            raise ImportError("yaml (PyYAML) module required")
         return yaml.dump(data)
 
     if formattype == 'json':
